#ifndef _SAM3XA_PIO_COMPONENT_
#define _SAM3XA_PIO_COMPONENT_

/*! @brief [Parallel Input/Output Controller](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=618) */
typedef struct
{
  __O uint32_t PIO_PER; /*! @brief [PIO Enable Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=633) */
  __O uint32_t PIO_PDR; /*! @brief [PIO Disable Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=634) */
  __I uint32_t PIO_PSR; /*! @brief [PIO Status Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=635) */
  __I uint32_t Reserved1[1];
  __O uint32_t PIO_OER; /*! @brief [Output Enable Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=636) */
  __O uint32_t PIO_ODR; /*! @brief [Output Disable Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=637) */
  __I uint32_t PIO_OSR; /*! @brief [Output Status Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=638) */
  __I uint32_t Reserved2[1];
  __O uint32_t PIO_IFER; /*! @brief [Glitch Input Filter Enable Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=639) */
  __O uint32_t PIO_IFDR; /*! @brief [Glitch Input Filter Disable Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=640) */
  __I uint32_t PIO_IFSR; /*! @brief [Glitch Input Filter Status Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=641) */
  __I uint32_t Reserved3[1];
  __O uint32_t PIO_SODR;  /*! @brief [Set Output Data Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=642) */
  __O uint32_t PIO_CODR;  /*! @brief [Clear Output Data Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=643) */
  __IO uint32_t PIO_ODSR; /*! @brief [Output Data Status Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=644) */
  __I uint32_t PIO_PDSR;  /*! @brief [Pin Data Status Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=645) */
  __O uint32_t PIO_IER;   /*! @brief [Interrupt Enable Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=646) */
  __O uint32_t PIO_IDR;   /*! @brief [Interrupt Disable Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=647) */
  __I uint32_t PIO_IMR;   /*! @brief [Interrupt Mask Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=648) */
  __I uint32_t PIO_ISR;   /*! @brief [Interrupt Status Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=649) */
  __O uint32_t PIO_MDER;  /*! @brief [Multi-driver Enable Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=650) */
  __O uint32_t PIO_MDDR;  /*! @brief [Multi-driver Disable Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=651) */
  __I uint32_t PIO_MDSR;  /*! @brief [Multi-driver Status Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=652) */
  __I uint32_t Reserved4[1];
  __O uint32_t PIO_PUDR; /*! @brief [Pull-up Disable Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=653) */
  __O uint32_t PIO_PUER; /*! @brief [Pull-up Enable Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=654) */
  __I uint32_t PIO_PUSR; /*! @brief [Pad Pull-up Status Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=655) */
  __I uint32_t Reserved5[1];
  __IO uint32_t PIO_ABSR; /*! @brief [Peripheral AB Select Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=656) */
  __I uint32_t Reserved6[3];
  __O uint32_t PIO_SCIFSR; /*! @brief [System Clock Glitch Input Filter Select Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=657) */
  __O uint32_t PIO_DIFSR;  /*! @brief [Debouncing Input Filter Select Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=658) */
  __I uint32_t PIO_IFDGSR; /*! @brief [Glitch or Debouncing Input Filter Clock Selection Status Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=659) */
  __IO uint32_t PIO_SCDR;  /*! @brief [Slow Clock Divider Debouncing Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=660) */
  __I uint32_t Reserved7[4];
  __O uint32_t PIO_OWER; /*! @brief [Output Write Enable](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=661) */
  __O uint32_t PIO_OWDR; /*! @brief [Output Write Disable](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=662) */
  __I uint32_t PIO_OWSR; /*! @brief [Output Write Status Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=663) */
  __I uint32_t Reserved8[1];
  __O uint32_t PIO_AIMER; /*! @brief [Additional Interrupt Modes Enable Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=664) */
  __O uint32_t PIO_AIMDR; /*! @brief [Additional Interrupt Modes Disables Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=665) */
  __I uint32_t PIO_AIMMR; /*! @brief [Additional Interrupt Modes Mask Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=666) */
  __I uint32_t Reserved9[1];
  __O uint32_t PIO_ESR;  /*! @brief [Edge Select Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=667) */
  __O uint32_t PIO_LSR;  /*! @brief [Level Select Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=668) */
  __I uint32_t PIO_ELSR; /*! @brief [Edge/Level Status Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=669) */
  __I uint32_t Reserved10[1];
  __O uint32_t PIO_FELLSR; /*! @brief [Falling Edge/Low Level Select Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=670) */
  __O uint32_t PIO_REHLSR; /*! @brief [Rising Edge/ High Level Select Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=671) */
  __I uint32_t PIO_FRLHSR; /*! @brief [Fall/Rise - Low/High Status Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=672) */
  __I uint32_t Reserved11[1];
  __I uint32_t PIO_LOCKSR; /*! @brief [Lock Status](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=673) */
  __IO uint32_t PIO_WPMR;  /*! @brief [Write Protect Mode Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=674) */
  __I uint32_t PIO_WPSR;   /*! @brief [Write Protect Status Register](https://code.fbi.h-da.de/eingebettete-systeme/arduino-due/cmsis/-/raw/main/docs/datasheet.pdf#page=675) */
} Pio;

#define PIO_PER_P0 (0x1u << 0)
#define PIO_PER_P1 (0x1u << 1)
#define PIO_PER_P2 (0x1u << 2)
#define PIO_PER_P3 (0x1u << 3)
#define PIO_PER_P4 (0x1u << 4)
#define PIO_PER_P5 (0x1u << 5)
#define PIO_PER_P6 (0x1u << 6)
#define PIO_PER_P7 (0x1u << 7)
#define PIO_PER_P8 (0x1u << 8)
#define PIO_PER_P9 (0x1u << 9)
#define PIO_PER_P10 (0x1u << 10)
#define PIO_PER_P11 (0x1u << 11)
#define PIO_PER_P12 (0x1u << 12)
#define PIO_PER_P13 (0x1u << 13)
#define PIO_PER_P14 (0x1u << 14)
#define PIO_PER_P15 (0x1u << 15)
#define PIO_PER_P16 (0x1u << 16)
#define PIO_PER_P17 (0x1u << 17)
#define PIO_PER_P18 (0x1u << 18)
#define PIO_PER_P19 (0x1u << 19)
#define PIO_PER_P20 (0x1u << 20)
#define PIO_PER_P21 (0x1u << 21)
#define PIO_PER_P22 (0x1u << 22)
#define PIO_PER_P23 (0x1u << 23)
#define PIO_PER_P24 (0x1u << 24)
#define PIO_PER_P25 (0x1u << 25)
#define PIO_PER_P26 (0x1u << 26)
#define PIO_PER_P27 (0x1u << 27)
#define PIO_PER_P28 (0x1u << 28)
#define PIO_PER_P29 (0x1u << 29)
#define PIO_PER_P30 (0x1u << 30)
#define PIO_PER_P31 (0x1u << 31)

#define PIO_PDR_P0 (0x1u << 0)
#define PIO_PDR_P1 (0x1u << 1)
#define PIO_PDR_P2 (0x1u << 2)
#define PIO_PDR_P3 (0x1u << 3)
#define PIO_PDR_P4 (0x1u << 4)
#define PIO_PDR_P5 (0x1u << 5)
#define PIO_PDR_P6 (0x1u << 6)
#define PIO_PDR_P7 (0x1u << 7)
#define PIO_PDR_P8 (0x1u << 8)
#define PIO_PDR_P9 (0x1u << 9)
#define PIO_PDR_P10 (0x1u << 10)
#define PIO_PDR_P11 (0x1u << 11)
#define PIO_PDR_P12 (0x1u << 12)
#define PIO_PDR_P13 (0x1u << 13)
#define PIO_PDR_P14 (0x1u << 14)
#define PIO_PDR_P15 (0x1u << 15)
#define PIO_PDR_P16 (0x1u << 16)
#define PIO_PDR_P17 (0x1u << 17)
#define PIO_PDR_P18 (0x1u << 18)
#define PIO_PDR_P19 (0x1u << 19)
#define PIO_PDR_P20 (0x1u << 20)
#define PIO_PDR_P21 (0x1u << 21)
#define PIO_PDR_P22 (0x1u << 22)
#define PIO_PDR_P23 (0x1u << 23)
#define PIO_PDR_P24 (0x1u << 24)
#define PIO_PDR_P25 (0x1u << 25)
#define PIO_PDR_P26 (0x1u << 26)
#define PIO_PDR_P27 (0x1u << 27)
#define PIO_PDR_P28 (0x1u << 28)
#define PIO_PDR_P29 (0x1u << 29)
#define PIO_PDR_P30 (0x1u << 30)
#define PIO_PDR_P31 (0x1u << 31)

#define PIO_PSR_P0 (0x1u << 0)
#define PIO_PSR_P1 (0x1u << 1)
#define PIO_PSR_P2 (0x1u << 2)
#define PIO_PSR_P3 (0x1u << 3)
#define PIO_PSR_P4 (0x1u << 4)
#define PIO_PSR_P5 (0x1u << 5)
#define PIO_PSR_P6 (0x1u << 6)
#define PIO_PSR_P7 (0x1u << 7)
#define PIO_PSR_P8 (0x1u << 8)
#define PIO_PSR_P9 (0x1u << 9)
#define PIO_PSR_P10 (0x1u << 10)
#define PIO_PSR_P11 (0x1u << 11)
#define PIO_PSR_P12 (0x1u << 12)
#define PIO_PSR_P13 (0x1u << 13)
#define PIO_PSR_P14 (0x1u << 14)
#define PIO_PSR_P15 (0x1u << 15)
#define PIO_PSR_P16 (0x1u << 16)
#define PIO_PSR_P17 (0x1u << 17)
#define PIO_PSR_P18 (0x1u << 18)
#define PIO_PSR_P19 (0x1u << 19)
#define PIO_PSR_P20 (0x1u << 20)
#define PIO_PSR_P21 (0x1u << 21)
#define PIO_PSR_P22 (0x1u << 22)
#define PIO_PSR_P23 (0x1u << 23)
#define PIO_PSR_P24 (0x1u << 24)
#define PIO_PSR_P25 (0x1u << 25)
#define PIO_PSR_P26 (0x1u << 26)
#define PIO_PSR_P27 (0x1u << 27)
#define PIO_PSR_P28 (0x1u << 28)
#define PIO_PSR_P29 (0x1u << 29)
#define PIO_PSR_P30 (0x1u << 30)
#define PIO_PSR_P31 (0x1u << 31)

#define PIO_OER_P0 (0x1u << 0)   
#define PIO_OER_P1 (0x1u << 1)   
#define PIO_OER_P2 (0x1u << 2)   
#define PIO_OER_P3 (0x1u << 3)   
#define PIO_OER_P4 (0x1u << 4)   
#define PIO_OER_P5 (0x1u << 5)   
#define PIO_OER_P6 (0x1u << 6)   
#define PIO_OER_P7 (0x1u << 7)   
#define PIO_OER_P8 (0x1u << 8)   
#define PIO_OER_P9 (0x1u << 9)   
#define PIO_OER_P10 (0x1u << 10) 
#define PIO_OER_P11 (0x1u << 11) 
#define PIO_OER_P12 (0x1u << 12) 
#define PIO_OER_P13 (0x1u << 13) 
#define PIO_OER_P14 (0x1u << 14) 
#define PIO_OER_P15 (0x1u << 15) 
#define PIO_OER_P16 (0x1u << 16) 
#define PIO_OER_P17 (0x1u << 17) 
#define PIO_OER_P18 (0x1u << 18) 
#define PIO_OER_P19 (0x1u << 19) 
#define PIO_OER_P20 (0x1u << 20) 
#define PIO_OER_P21 (0x1u << 21) 
#define PIO_OER_P22 (0x1u << 22) 
#define PIO_OER_P23 (0x1u << 23) 
#define PIO_OER_P24 (0x1u << 24) 
#define PIO_OER_P25 (0x1u << 25) 
#define PIO_OER_P26 (0x1u << 26) 
#define PIO_OER_P27 (0x1u << 27) 
#define PIO_OER_P28 (0x1u << 28) 
#define PIO_OER_P29 (0x1u << 29) 
#define PIO_OER_P30 (0x1u << 30) 
#define PIO_OER_P31 (0x1u << 31) 

#define PIO_ODR_P0 (0x1u << 0)   
#define PIO_ODR_P1 (0x1u << 1)   
#define PIO_ODR_P2 (0x1u << 2)   
#define PIO_ODR_P3 (0x1u << 3)   
#define PIO_ODR_P4 (0x1u << 4)   
#define PIO_ODR_P5 (0x1u << 5)   
#define PIO_ODR_P6 (0x1u << 6)   
#define PIO_ODR_P7 (0x1u << 7)   
#define PIO_ODR_P8 (0x1u << 8)   
#define PIO_ODR_P9 (0x1u << 9)   
#define PIO_ODR_P10 (0x1u << 10) 
#define PIO_ODR_P11 (0x1u << 11) 
#define PIO_ODR_P12 (0x1u << 12) 
#define PIO_ODR_P13 (0x1u << 13) 
#define PIO_ODR_P14 (0x1u << 14) 
#define PIO_ODR_P15 (0x1u << 15) 
#define PIO_ODR_P16 (0x1u << 16) 
#define PIO_ODR_P17 (0x1u << 17) 
#define PIO_ODR_P18 (0x1u << 18) 
#define PIO_ODR_P19 (0x1u << 19) 
#define PIO_ODR_P20 (0x1u << 20) 
#define PIO_ODR_P21 (0x1u << 21) 
#define PIO_ODR_P22 (0x1u << 22) 
#define PIO_ODR_P23 (0x1u << 23) 
#define PIO_ODR_P24 (0x1u << 24) 
#define PIO_ODR_P25 (0x1u << 25) 
#define PIO_ODR_P26 (0x1u << 26) 
#define PIO_ODR_P27 (0x1u << 27) 
#define PIO_ODR_P28 (0x1u << 28) 
#define PIO_ODR_P29 (0x1u << 29) 
#define PIO_ODR_P30 (0x1u << 30) 
#define PIO_ODR_P31 (0x1u << 31) 

#define PIO_OSR_P0 (0x1u << 0)   
#define PIO_OSR_P1 (0x1u << 1)   
#define PIO_OSR_P2 (0x1u << 2)   
#define PIO_OSR_P3 (0x1u << 3)   
#define PIO_OSR_P4 (0x1u << 4)   
#define PIO_OSR_P5 (0x1u << 5)   
#define PIO_OSR_P6 (0x1u << 6)   
#define PIO_OSR_P7 (0x1u << 7)   
#define PIO_OSR_P8 (0x1u << 8)   
#define PIO_OSR_P9 (0x1u << 9)   
#define PIO_OSR_P10 (0x1u << 10) 
#define PIO_OSR_P11 (0x1u << 11) 
#define PIO_OSR_P12 (0x1u << 12) 
#define PIO_OSR_P13 (0x1u << 13) 
#define PIO_OSR_P14 (0x1u << 14) 
#define PIO_OSR_P15 (0x1u << 15) 
#define PIO_OSR_P16 (0x1u << 16) 
#define PIO_OSR_P17 (0x1u << 17) 
#define PIO_OSR_P18 (0x1u << 18) 
#define PIO_OSR_P19 (0x1u << 19) 
#define PIO_OSR_P20 (0x1u << 20) 
#define PIO_OSR_P21 (0x1u << 21) 
#define PIO_OSR_P22 (0x1u << 22) 
#define PIO_OSR_P23 (0x1u << 23) 
#define PIO_OSR_P24 (0x1u << 24) 
#define PIO_OSR_P25 (0x1u << 25) 
#define PIO_OSR_P26 (0x1u << 26) 
#define PIO_OSR_P27 (0x1u << 27) 
#define PIO_OSR_P28 (0x1u << 28) 
#define PIO_OSR_P29 (0x1u << 29) 
#define PIO_OSR_P30 (0x1u << 30) 
#define PIO_OSR_P31 (0x1u << 31) 

#define PIO_IFER_P0 (0x1u << 0)   
#define PIO_IFER_P1 (0x1u << 1)   
#define PIO_IFER_P2 (0x1u << 2)   
#define PIO_IFER_P3 (0x1u << 3)   
#define PIO_IFER_P4 (0x1u << 4)   
#define PIO_IFER_P5 (0x1u << 5)   
#define PIO_IFER_P6 (0x1u << 6)   
#define PIO_IFER_P7 (0x1u << 7)   
#define PIO_IFER_P8 (0x1u << 8)   
#define PIO_IFER_P9 (0x1u << 9)   
#define PIO_IFER_P10 (0x1u << 10) 
#define PIO_IFER_P11 (0x1u << 11) 
#define PIO_IFER_P12 (0x1u << 12) 
#define PIO_IFER_P13 (0x1u << 13) 
#define PIO_IFER_P14 (0x1u << 14) 
#define PIO_IFER_P15 (0x1u << 15) 
#define PIO_IFER_P16 (0x1u << 16) 
#define PIO_IFER_P17 (0x1u << 17) 
#define PIO_IFER_P18 (0x1u << 18) 
#define PIO_IFER_P19 (0x1u << 19) 
#define PIO_IFER_P20 (0x1u << 20) 
#define PIO_IFER_P21 (0x1u << 21) 
#define PIO_IFER_P22 (0x1u << 22) 
#define PIO_IFER_P23 (0x1u << 23) 
#define PIO_IFER_P24 (0x1u << 24) 
#define PIO_IFER_P25 (0x1u << 25) 
#define PIO_IFER_P26 (0x1u << 26) 
#define PIO_IFER_P27 (0x1u << 27) 
#define PIO_IFER_P28 (0x1u << 28) 
#define PIO_IFER_P29 (0x1u << 29) 
#define PIO_IFER_P30 (0x1u << 30) 
#define PIO_IFER_P31 (0x1u << 31) 

#define PIO_IFDR_P0 (0x1u << 0)   
#define PIO_IFDR_P1 (0x1u << 1)   
#define PIO_IFDR_P2 (0x1u << 2)   
#define PIO_IFDR_P3 (0x1u << 3)   
#define PIO_IFDR_P4 (0x1u << 4)   
#define PIO_IFDR_P5 (0x1u << 5)   
#define PIO_IFDR_P6 (0x1u << 6)   
#define PIO_IFDR_P7 (0x1u << 7)   
#define PIO_IFDR_P8 (0x1u << 8)   
#define PIO_IFDR_P9 (0x1u << 9)   
#define PIO_IFDR_P10 (0x1u << 10) 
#define PIO_IFDR_P11 (0x1u << 11) 
#define PIO_IFDR_P12 (0x1u << 12) 
#define PIO_IFDR_P13 (0x1u << 13) 
#define PIO_IFDR_P14 (0x1u << 14) 
#define PIO_IFDR_P15 (0x1u << 15) 
#define PIO_IFDR_P16 (0x1u << 16) 
#define PIO_IFDR_P17 (0x1u << 17) 
#define PIO_IFDR_P18 (0x1u << 18) 
#define PIO_IFDR_P19 (0x1u << 19) 
#define PIO_IFDR_P20 (0x1u << 20) 
#define PIO_IFDR_P21 (0x1u << 21) 
#define PIO_IFDR_P22 (0x1u << 22) 
#define PIO_IFDR_P23 (0x1u << 23) 
#define PIO_IFDR_P24 (0x1u << 24) 
#define PIO_IFDR_P25 (0x1u << 25) 
#define PIO_IFDR_P26 (0x1u << 26) 
#define PIO_IFDR_P27 (0x1u << 27) 
#define PIO_IFDR_P28 (0x1u << 28) 
#define PIO_IFDR_P29 (0x1u << 29) 
#define PIO_IFDR_P30 (0x1u << 30) 
#define PIO_IFDR_P31 (0x1u << 31) 

#define PIO_IFSR_P0 (0x1u << 0)   
#define PIO_IFSR_P1 (0x1u << 1)   
#define PIO_IFSR_P2 (0x1u << 2)   
#define PIO_IFSR_P3 (0x1u << 3)   
#define PIO_IFSR_P4 (0x1u << 4)   
#define PIO_IFSR_P5 (0x1u << 5)   
#define PIO_IFSR_P6 (0x1u << 6)   
#define PIO_IFSR_P7 (0x1u << 7)   
#define PIO_IFSR_P8 (0x1u << 8)   
#define PIO_IFSR_P9 (0x1u << 9)   
#define PIO_IFSR_P10 (0x1u << 10) 
#define PIO_IFSR_P11 (0x1u << 11) 
#define PIO_IFSR_P12 (0x1u << 12) 
#define PIO_IFSR_P13 (0x1u << 13) 
#define PIO_IFSR_P14 (0x1u << 14) 
#define PIO_IFSR_P15 (0x1u << 15) 
#define PIO_IFSR_P16 (0x1u << 16) 
#define PIO_IFSR_P17 (0x1u << 17) 
#define PIO_IFSR_P18 (0x1u << 18) 
#define PIO_IFSR_P19 (0x1u << 19) 
#define PIO_IFSR_P20 (0x1u << 20) 
#define PIO_IFSR_P21 (0x1u << 21) 
#define PIO_IFSR_P22 (0x1u << 22) 
#define PIO_IFSR_P23 (0x1u << 23) 
#define PIO_IFSR_P24 (0x1u << 24) 
#define PIO_IFSR_P25 (0x1u << 25) 
#define PIO_IFSR_P26 (0x1u << 26) 
#define PIO_IFSR_P27 (0x1u << 27) 
#define PIO_IFSR_P28 (0x1u << 28) 
#define PIO_IFSR_P29 (0x1u << 29) 
#define PIO_IFSR_P30 (0x1u << 30) 
#define PIO_IFSR_P31 (0x1u << 31) 

#define PIO_SODR_P0 (0x1u << 0)   
#define PIO_SODR_P1 (0x1u << 1)   
#define PIO_SODR_P2 (0x1u << 2)   
#define PIO_SODR_P3 (0x1u << 3)   
#define PIO_SODR_P4 (0x1u << 4)   
#define PIO_SODR_P5 (0x1u << 5)   
#define PIO_SODR_P6 (0x1u << 6)   
#define PIO_SODR_P7 (0x1u << 7)   
#define PIO_SODR_P8 (0x1u << 8)   
#define PIO_SODR_P9 (0x1u << 9)   
#define PIO_SODR_P10 (0x1u << 10) 
#define PIO_SODR_P11 (0x1u << 11) 
#define PIO_SODR_P12 (0x1u << 12) 
#define PIO_SODR_P13 (0x1u << 13) 
#define PIO_SODR_P14 (0x1u << 14) 
#define PIO_SODR_P15 (0x1u << 15) 
#define PIO_SODR_P16 (0x1u << 16) 
#define PIO_SODR_P17 (0x1u << 17) 
#define PIO_SODR_P18 (0x1u << 18) 
#define PIO_SODR_P19 (0x1u << 19) 
#define PIO_SODR_P20 (0x1u << 20) 
#define PIO_SODR_P21 (0x1u << 21) 
#define PIO_SODR_P22 (0x1u << 22) 
#define PIO_SODR_P23 (0x1u << 23) 
#define PIO_SODR_P24 (0x1u << 24) 
#define PIO_SODR_P25 (0x1u << 25) 
#define PIO_SODR_P26 (0x1u << 26) 
#define PIO_SODR_P27 (0x1u << 27) 
#define PIO_SODR_P28 (0x1u << 28) 
#define PIO_SODR_P29 (0x1u << 29) 
#define PIO_SODR_P30 (0x1u << 30) 
#define PIO_SODR_P31 (0x1u << 31) 

#define PIO_CODR_P0 (0x1u << 0)   
#define PIO_CODR_P1 (0x1u << 1)   
#define PIO_CODR_P2 (0x1u << 2)   
#define PIO_CODR_P3 (0x1u << 3)   
#define PIO_CODR_P4 (0x1u << 4)   
#define PIO_CODR_P5 (0x1u << 5)   
#define PIO_CODR_P6 (0x1u << 6)   
#define PIO_CODR_P7 (0x1u << 7)   
#define PIO_CODR_P8 (0x1u << 8)   
#define PIO_CODR_P9 (0x1u << 9)   
#define PIO_CODR_P10 (0x1u << 10) 
#define PIO_CODR_P11 (0x1u << 11) 
#define PIO_CODR_P12 (0x1u << 12) 
#define PIO_CODR_P13 (0x1u << 13) 
#define PIO_CODR_P14 (0x1u << 14) 
#define PIO_CODR_P15 (0x1u << 15) 
#define PIO_CODR_P16 (0x1u << 16) 
#define PIO_CODR_P17 (0x1u << 17) 
#define PIO_CODR_P18 (0x1u << 18) 
#define PIO_CODR_P19 (0x1u << 19) 
#define PIO_CODR_P20 (0x1u << 20) 
#define PIO_CODR_P21 (0x1u << 21) 
#define PIO_CODR_P22 (0x1u << 22) 
#define PIO_CODR_P23 (0x1u << 23) 
#define PIO_CODR_P24 (0x1u << 24) 
#define PIO_CODR_P25 (0x1u << 25) 
#define PIO_CODR_P26 (0x1u << 26) 
#define PIO_CODR_P27 (0x1u << 27) 
#define PIO_CODR_P28 (0x1u << 28) 
#define PIO_CODR_P29 (0x1u << 29) 
#define PIO_CODR_P30 (0x1u << 30) 
#define PIO_CODR_P31 (0x1u << 31) 

#define PIO_ODSR_P0 (0x1u << 0)   
#define PIO_ODSR_P1 (0x1u << 1)   
#define PIO_ODSR_P2 (0x1u << 2)   
#define PIO_ODSR_P3 (0x1u << 3)   
#define PIO_ODSR_P4 (0x1u << 4)   
#define PIO_ODSR_P5 (0x1u << 5)   
#define PIO_ODSR_P6 (0x1u << 6)   
#define PIO_ODSR_P7 (0x1u << 7)   
#define PIO_ODSR_P8 (0x1u << 8)   
#define PIO_ODSR_P9 (0x1u << 9)   
#define PIO_ODSR_P10 (0x1u << 10) 
#define PIO_ODSR_P11 (0x1u << 11) 
#define PIO_ODSR_P12 (0x1u << 12) 
#define PIO_ODSR_P13 (0x1u << 13) 
#define PIO_ODSR_P14 (0x1u << 14) 
#define PIO_ODSR_P15 (0x1u << 15) 
#define PIO_ODSR_P16 (0x1u << 16) 
#define PIO_ODSR_P17 (0x1u << 17) 
#define PIO_ODSR_P18 (0x1u << 18) 
#define PIO_ODSR_P19 (0x1u << 19) 
#define PIO_ODSR_P20 (0x1u << 20) 
#define PIO_ODSR_P21 (0x1u << 21) 
#define PIO_ODSR_P22 (0x1u << 22) 
#define PIO_ODSR_P23 (0x1u << 23) 
#define PIO_ODSR_P24 (0x1u << 24) 
#define PIO_ODSR_P25 (0x1u << 25) 
#define PIO_ODSR_P26 (0x1u << 26) 
#define PIO_ODSR_P27 (0x1u << 27) 
#define PIO_ODSR_P28 (0x1u << 28) 
#define PIO_ODSR_P29 (0x1u << 29) 
#define PIO_ODSR_P30 (0x1u << 30) 
#define PIO_ODSR_P31 (0x1u << 31) 

#define PIO_PDSR_P0 (0x1u << 0)   
#define PIO_PDSR_P1 (0x1u << 1)   
#define PIO_PDSR_P2 (0x1u << 2)   
#define PIO_PDSR_P3 (0x1u << 3)   
#define PIO_PDSR_P4 (0x1u << 4)   
#define PIO_PDSR_P5 (0x1u << 5)   
#define PIO_PDSR_P6 (0x1u << 6)   
#define PIO_PDSR_P7 (0x1u << 7)   
#define PIO_PDSR_P8 (0x1u << 8)   
#define PIO_PDSR_P9 (0x1u << 9)   
#define PIO_PDSR_P10 (0x1u << 10) 
#define PIO_PDSR_P11 (0x1u << 11) 
#define PIO_PDSR_P12 (0x1u << 12) 
#define PIO_PDSR_P13 (0x1u << 13) 
#define PIO_PDSR_P14 (0x1u << 14) 
#define PIO_PDSR_P15 (0x1u << 15) 
#define PIO_PDSR_P16 (0x1u << 16) 
#define PIO_PDSR_P17 (0x1u << 17) 
#define PIO_PDSR_P18 (0x1u << 18) 
#define PIO_PDSR_P19 (0x1u << 19) 
#define PIO_PDSR_P20 (0x1u << 20) 
#define PIO_PDSR_P21 (0x1u << 21) 
#define PIO_PDSR_P22 (0x1u << 22) 
#define PIO_PDSR_P23 (0x1u << 23) 
#define PIO_PDSR_P24 (0x1u << 24) 
#define PIO_PDSR_P25 (0x1u << 25) 
#define PIO_PDSR_P26 (0x1u << 26) 
#define PIO_PDSR_P27 (0x1u << 27) 
#define PIO_PDSR_P28 (0x1u << 28) 
#define PIO_PDSR_P29 (0x1u << 29) 
#define PIO_PDSR_P30 (0x1u << 30) 
#define PIO_PDSR_P31 (0x1u << 31) 

#define PIO_IER_P0 (0x1u << 0)   
#define PIO_IER_P1 (0x1u << 1)   
#define PIO_IER_P2 (0x1u << 2)   
#define PIO_IER_P3 (0x1u << 3)   
#define PIO_IER_P4 (0x1u << 4)   
#define PIO_IER_P5 (0x1u << 5)   
#define PIO_IER_P6 (0x1u << 6)   
#define PIO_IER_P7 (0x1u << 7)   
#define PIO_IER_P8 (0x1u << 8)   
#define PIO_IER_P9 (0x1u << 9)   
#define PIO_IER_P10 (0x1u << 10) 
#define PIO_IER_P11 (0x1u << 11) 
#define PIO_IER_P12 (0x1u << 12) 
#define PIO_IER_P13 (0x1u << 13) 
#define PIO_IER_P14 (0x1u << 14) 
#define PIO_IER_P15 (0x1u << 15) 
#define PIO_IER_P16 (0x1u << 16) 
#define PIO_IER_P17 (0x1u << 17) 
#define PIO_IER_P18 (0x1u << 18) 
#define PIO_IER_P19 (0x1u << 19) 
#define PIO_IER_P20 (0x1u << 20) 
#define PIO_IER_P21 (0x1u << 21) 
#define PIO_IER_P22 (0x1u << 22) 
#define PIO_IER_P23 (0x1u << 23) 
#define PIO_IER_P24 (0x1u << 24) 
#define PIO_IER_P25 (0x1u << 25) 
#define PIO_IER_P26 (0x1u << 26) 
#define PIO_IER_P27 (0x1u << 27) 
#define PIO_IER_P28 (0x1u << 28) 
#define PIO_IER_P29 (0x1u << 29) 
#define PIO_IER_P30 (0x1u << 30) 
#define PIO_IER_P31 (0x1u << 31) 

#define PIO_IDR_P0 (0x1u << 0)   
#define PIO_IDR_P1 (0x1u << 1)   
#define PIO_IDR_P2 (0x1u << 2)   
#define PIO_IDR_P3 (0x1u << 3)   
#define PIO_IDR_P4 (0x1u << 4)   
#define PIO_IDR_P5 (0x1u << 5)   
#define PIO_IDR_P6 (0x1u << 6)   
#define PIO_IDR_P7 (0x1u << 7)   
#define PIO_IDR_P8 (0x1u << 8)   
#define PIO_IDR_P9 (0x1u << 9)   
#define PIO_IDR_P10 (0x1u << 10) 
#define PIO_IDR_P11 (0x1u << 11) 
#define PIO_IDR_P12 (0x1u << 12) 
#define PIO_IDR_P13 (0x1u << 13) 
#define PIO_IDR_P14 (0x1u << 14) 
#define PIO_IDR_P15 (0x1u << 15) 
#define PIO_IDR_P16 (0x1u << 16) 
#define PIO_IDR_P17 (0x1u << 17) 
#define PIO_IDR_P18 (0x1u << 18) 
#define PIO_IDR_P19 (0x1u << 19) 
#define PIO_IDR_P20 (0x1u << 20) 
#define PIO_IDR_P21 (0x1u << 21) 
#define PIO_IDR_P22 (0x1u << 22) 
#define PIO_IDR_P23 (0x1u << 23) 
#define PIO_IDR_P24 (0x1u << 24) 
#define PIO_IDR_P25 (0x1u << 25) 
#define PIO_IDR_P26 (0x1u << 26) 
#define PIO_IDR_P27 (0x1u << 27) 
#define PIO_IDR_P28 (0x1u << 28) 
#define PIO_IDR_P29 (0x1u << 29) 
#define PIO_IDR_P30 (0x1u << 30) 
#define PIO_IDR_P31 (0x1u << 31) 

#define PIO_IMR_P0 (0x1u << 0)   
#define PIO_IMR_P1 (0x1u << 1)   
#define PIO_IMR_P2 (0x1u << 2)   
#define PIO_IMR_P3 (0x1u << 3)   
#define PIO_IMR_P4 (0x1u << 4)   
#define PIO_IMR_P5 (0x1u << 5)   
#define PIO_IMR_P6 (0x1u << 6)   
#define PIO_IMR_P7 (0x1u << 7)   
#define PIO_IMR_P8 (0x1u << 8)   
#define PIO_IMR_P9 (0x1u << 9)   
#define PIO_IMR_P10 (0x1u << 10) 
#define PIO_IMR_P11 (0x1u << 11) 
#define PIO_IMR_P12 (0x1u << 12) 
#define PIO_IMR_P13 (0x1u << 13) 
#define PIO_IMR_P14 (0x1u << 14) 
#define PIO_IMR_P15 (0x1u << 15) 
#define PIO_IMR_P16 (0x1u << 16) 
#define PIO_IMR_P17 (0x1u << 17) 
#define PIO_IMR_P18 (0x1u << 18) 
#define PIO_IMR_P19 (0x1u << 19) 
#define PIO_IMR_P20 (0x1u << 20) 
#define PIO_IMR_P21 (0x1u << 21) 
#define PIO_IMR_P22 (0x1u << 22) 
#define PIO_IMR_P23 (0x1u << 23) 
#define PIO_IMR_P24 (0x1u << 24) 
#define PIO_IMR_P25 (0x1u << 25) 
#define PIO_IMR_P26 (0x1u << 26) 
#define PIO_IMR_P27 (0x1u << 27) 
#define PIO_IMR_P28 (0x1u << 28) 
#define PIO_IMR_P29 (0x1u << 29) 
#define PIO_IMR_P30 (0x1u << 30) 
#define PIO_IMR_P31 (0x1u << 31) 

#define PIO_ISR_P0 (0x1u << 0)   
#define PIO_ISR_P1 (0x1u << 1)   
#define PIO_ISR_P2 (0x1u << 2)   
#define PIO_ISR_P3 (0x1u << 3)   
#define PIO_ISR_P4 (0x1u << 4)   
#define PIO_ISR_P5 (0x1u << 5)   
#define PIO_ISR_P6 (0x1u << 6)   
#define PIO_ISR_P7 (0x1u << 7)   
#define PIO_ISR_P8 (0x1u << 8)   
#define PIO_ISR_P9 (0x1u << 9)   
#define PIO_ISR_P10 (0x1u << 10) 
#define PIO_ISR_P11 (0x1u << 11) 
#define PIO_ISR_P12 (0x1u << 12) 
#define PIO_ISR_P13 (0x1u << 13) 
#define PIO_ISR_P14 (0x1u << 14) 
#define PIO_ISR_P15 (0x1u << 15) 
#define PIO_ISR_P16 (0x1u << 16) 
#define PIO_ISR_P17 (0x1u << 17) 
#define PIO_ISR_P18 (0x1u << 18) 
#define PIO_ISR_P19 (0x1u << 19) 
#define PIO_ISR_P20 (0x1u << 20) 
#define PIO_ISR_P21 (0x1u << 21) 
#define PIO_ISR_P22 (0x1u << 22) 
#define PIO_ISR_P23 (0x1u << 23) 
#define PIO_ISR_P24 (0x1u << 24) 
#define PIO_ISR_P25 (0x1u << 25) 
#define PIO_ISR_P26 (0x1u << 26) 
#define PIO_ISR_P27 (0x1u << 27) 
#define PIO_ISR_P28 (0x1u << 28) 
#define PIO_ISR_P29 (0x1u << 29) 
#define PIO_ISR_P30 (0x1u << 30) 
#define PIO_ISR_P31 (0x1u << 31) 

#define PIO_MDER_P0 (0x1u << 0)   
#define PIO_MDER_P1 (0x1u << 1)   
#define PIO_MDER_P2 (0x1u << 2)   
#define PIO_MDER_P3 (0x1u << 3)   
#define PIO_MDER_P4 (0x1u << 4)   
#define PIO_MDER_P5 (0x1u << 5)   
#define PIO_MDER_P6 (0x1u << 6)   
#define PIO_MDER_P7 (0x1u << 7)   
#define PIO_MDER_P8 (0x1u << 8)   
#define PIO_MDER_P9 (0x1u << 9)   
#define PIO_MDER_P10 (0x1u << 10) 
#define PIO_MDER_P11 (0x1u << 11) 
#define PIO_MDER_P12 (0x1u << 12) 
#define PIO_MDER_P13 (0x1u << 13) 
#define PIO_MDER_P14 (0x1u << 14) 
#define PIO_MDER_P15 (0x1u << 15) 
#define PIO_MDER_P16 (0x1u << 16) 
#define PIO_MDER_P17 (0x1u << 17) 
#define PIO_MDER_P18 (0x1u << 18) 
#define PIO_MDER_P19 (0x1u << 19) 
#define PIO_MDER_P20 (0x1u << 20) 
#define PIO_MDER_P21 (0x1u << 21) 
#define PIO_MDER_P22 (0x1u << 22) 
#define PIO_MDER_P23 (0x1u << 23) 
#define PIO_MDER_P24 (0x1u << 24) 
#define PIO_MDER_P25 (0x1u << 25) 
#define PIO_MDER_P26 (0x1u << 26) 
#define PIO_MDER_P27 (0x1u << 27) 
#define PIO_MDER_P28 (0x1u << 28) 
#define PIO_MDER_P29 (0x1u << 29) 
#define PIO_MDER_P30 (0x1u << 30) 
#define PIO_MDER_P31 (0x1u << 31) 

#define PIO_MDDR_P0 (0x1u << 0)   
#define PIO_MDDR_P1 (0x1u << 1)   
#define PIO_MDDR_P2 (0x1u << 2)   
#define PIO_MDDR_P3 (0x1u << 3)   
#define PIO_MDDR_P4 (0x1u << 4)   
#define PIO_MDDR_P5 (0x1u << 5)   
#define PIO_MDDR_P6 (0x1u << 6)   
#define PIO_MDDR_P7 (0x1u << 7)   
#define PIO_MDDR_P8 (0x1u << 8)   
#define PIO_MDDR_P9 (0x1u << 9)   
#define PIO_MDDR_P10 (0x1u << 10) 
#define PIO_MDDR_P11 (0x1u << 11) 
#define PIO_MDDR_P12 (0x1u << 12) 
#define PIO_MDDR_P13 (0x1u << 13) 
#define PIO_MDDR_P14 (0x1u << 14) 
#define PIO_MDDR_P15 (0x1u << 15) 
#define PIO_MDDR_P16 (0x1u << 16) 
#define PIO_MDDR_P17 (0x1u << 17) 
#define PIO_MDDR_P18 (0x1u << 18) 
#define PIO_MDDR_P19 (0x1u << 19) 
#define PIO_MDDR_P20 (0x1u << 20) 
#define PIO_MDDR_P21 (0x1u << 21) 
#define PIO_MDDR_P22 (0x1u << 22) 
#define PIO_MDDR_P23 (0x1u << 23) 
#define PIO_MDDR_P24 (0x1u << 24) 
#define PIO_MDDR_P25 (0x1u << 25) 
#define PIO_MDDR_P26 (0x1u << 26) 
#define PIO_MDDR_P27 (0x1u << 27) 
#define PIO_MDDR_P28 (0x1u << 28) 
#define PIO_MDDR_P29 (0x1u << 29) 
#define PIO_MDDR_P30 (0x1u << 30) 
#define PIO_MDDR_P31 (0x1u << 31) 

#define PIO_MDSR_P0 (0x1u << 0)   
#define PIO_MDSR_P1 (0x1u << 1)   
#define PIO_MDSR_P2 (0x1u << 2)   
#define PIO_MDSR_P3 (0x1u << 3)   
#define PIO_MDSR_P4 (0x1u << 4)   
#define PIO_MDSR_P5 (0x1u << 5)   
#define PIO_MDSR_P6 (0x1u << 6)   
#define PIO_MDSR_P7 (0x1u << 7)   
#define PIO_MDSR_P8 (0x1u << 8)   
#define PIO_MDSR_P9 (0x1u << 9)   
#define PIO_MDSR_P10 (0x1u << 10) 
#define PIO_MDSR_P11 (0x1u << 11) 
#define PIO_MDSR_P12 (0x1u << 12) 
#define PIO_MDSR_P13 (0x1u << 13) 
#define PIO_MDSR_P14 (0x1u << 14) 
#define PIO_MDSR_P15 (0x1u << 15) 
#define PIO_MDSR_P16 (0x1u << 16) 
#define PIO_MDSR_P17 (0x1u << 17) 
#define PIO_MDSR_P18 (0x1u << 18) 
#define PIO_MDSR_P19 (0x1u << 19) 
#define PIO_MDSR_P20 (0x1u << 20) 
#define PIO_MDSR_P21 (0x1u << 21) 
#define PIO_MDSR_P22 (0x1u << 22) 
#define PIO_MDSR_P23 (0x1u << 23) 
#define PIO_MDSR_P24 (0x1u << 24) 
#define PIO_MDSR_P25 (0x1u << 25) 
#define PIO_MDSR_P26 (0x1u << 26) 
#define PIO_MDSR_P27 (0x1u << 27) 
#define PIO_MDSR_P28 (0x1u << 28) 
#define PIO_MDSR_P29 (0x1u << 29) 
#define PIO_MDSR_P30 (0x1u << 30) 
#define PIO_MDSR_P31 (0x1u << 31) 

#define PIO_PUDR_P0 (0x1u << 0)   
#define PIO_PUDR_P1 (0x1u << 1)   
#define PIO_PUDR_P2 (0x1u << 2)   
#define PIO_PUDR_P3 (0x1u << 3)   
#define PIO_PUDR_P4 (0x1u << 4)   
#define PIO_PUDR_P5 (0x1u << 5)   
#define PIO_PUDR_P6 (0x1u << 6)   
#define PIO_PUDR_P7 (0x1u << 7)   
#define PIO_PUDR_P8 (0x1u << 8)   
#define PIO_PUDR_P9 (0x1u << 9)   
#define PIO_PUDR_P10 (0x1u << 10) 
#define PIO_PUDR_P11 (0x1u << 11) 
#define PIO_PUDR_P12 (0x1u << 12) 
#define PIO_PUDR_P13 (0x1u << 13) 
#define PIO_PUDR_P14 (0x1u << 14) 
#define PIO_PUDR_P15 (0x1u << 15) 
#define PIO_PUDR_P16 (0x1u << 16) 
#define PIO_PUDR_P17 (0x1u << 17) 
#define PIO_PUDR_P18 (0x1u << 18) 
#define PIO_PUDR_P19 (0x1u << 19) 
#define PIO_PUDR_P20 (0x1u << 20) 
#define PIO_PUDR_P21 (0x1u << 21) 
#define PIO_PUDR_P22 (0x1u << 22) 
#define PIO_PUDR_P23 (0x1u << 23) 
#define PIO_PUDR_P24 (0x1u << 24) 
#define PIO_PUDR_P25 (0x1u << 25) 
#define PIO_PUDR_P26 (0x1u << 26) 
#define PIO_PUDR_P27 (0x1u << 27) 
#define PIO_PUDR_P28 (0x1u << 28) 
#define PIO_PUDR_P29 (0x1u << 29) 
#define PIO_PUDR_P30 (0x1u << 30) 
#define PIO_PUDR_P31 (0x1u << 31) 

#define PIO_PUER_P0 (0x1u << 0)   
#define PIO_PUER_P1 (0x1u << 1)   
#define PIO_PUER_P2 (0x1u << 2)   
#define PIO_PUER_P3 (0x1u << 3)   
#define PIO_PUER_P4 (0x1u << 4)   
#define PIO_PUER_P5 (0x1u << 5)   
#define PIO_PUER_P6 (0x1u << 6)   
#define PIO_PUER_P7 (0x1u << 7)   
#define PIO_PUER_P8 (0x1u << 8)   
#define PIO_PUER_P9 (0x1u << 9)   
#define PIO_PUER_P10 (0x1u << 10) 
#define PIO_PUER_P11 (0x1u << 11) 
#define PIO_PUER_P12 (0x1u << 12) 
#define PIO_PUER_P13 (0x1u << 13) 
#define PIO_PUER_P14 (0x1u << 14) 
#define PIO_PUER_P15 (0x1u << 15) 
#define PIO_PUER_P16 (0x1u << 16) 
#define PIO_PUER_P17 (0x1u << 17) 
#define PIO_PUER_P18 (0x1u << 18) 
#define PIO_PUER_P19 (0x1u << 19) 
#define PIO_PUER_P20 (0x1u << 20) 
#define PIO_PUER_P21 (0x1u << 21) 
#define PIO_PUER_P22 (0x1u << 22) 
#define PIO_PUER_P23 (0x1u << 23) 
#define PIO_PUER_P24 (0x1u << 24) 
#define PIO_PUER_P25 (0x1u << 25) 
#define PIO_PUER_P26 (0x1u << 26) 
#define PIO_PUER_P27 (0x1u << 27) 
#define PIO_PUER_P28 (0x1u << 28) 
#define PIO_PUER_P29 (0x1u << 29) 
#define PIO_PUER_P30 (0x1u << 30) 
#define PIO_PUER_P31 (0x1u << 31) 

#define PIO_PUSR_P0 (0x1u << 0)   
#define PIO_PUSR_P1 (0x1u << 1)   
#define PIO_PUSR_P2 (0x1u << 2)   
#define PIO_PUSR_P3 (0x1u << 3)   
#define PIO_PUSR_P4 (0x1u << 4)   
#define PIO_PUSR_P5 (0x1u << 5)   
#define PIO_PUSR_P6 (0x1u << 6)   
#define PIO_PUSR_P7 (0x1u << 7)   
#define PIO_PUSR_P8 (0x1u << 8)   
#define PIO_PUSR_P9 (0x1u << 9)   
#define PIO_PUSR_P10 (0x1u << 10) 
#define PIO_PUSR_P11 (0x1u << 11) 
#define PIO_PUSR_P12 (0x1u << 12) 
#define PIO_PUSR_P13 (0x1u << 13) 
#define PIO_PUSR_P14 (0x1u << 14) 
#define PIO_PUSR_P15 (0x1u << 15) 
#define PIO_PUSR_P16 (0x1u << 16) 
#define PIO_PUSR_P17 (0x1u << 17) 
#define PIO_PUSR_P18 (0x1u << 18) 
#define PIO_PUSR_P19 (0x1u << 19) 
#define PIO_PUSR_P20 (0x1u << 20) 
#define PIO_PUSR_P21 (0x1u << 21) 
#define PIO_PUSR_P22 (0x1u << 22) 
#define PIO_PUSR_P23 (0x1u << 23) 
#define PIO_PUSR_P24 (0x1u << 24) 
#define PIO_PUSR_P25 (0x1u << 25) 
#define PIO_PUSR_P26 (0x1u << 26) 
#define PIO_PUSR_P27 (0x1u << 27) 
#define PIO_PUSR_P28 (0x1u << 28) 
#define PIO_PUSR_P29 (0x1u << 29) 
#define PIO_PUSR_P30 (0x1u << 30) 
#define PIO_PUSR_P31 (0x1u << 31) 

#define PIO_ABSR_P0 (0x1u << 0)   
#define PIO_ABSR_P1 (0x1u << 1)   
#define PIO_ABSR_P2 (0x1u << 2)   
#define PIO_ABSR_P3 (0x1u << 3)   
#define PIO_ABSR_P4 (0x1u << 4)   
#define PIO_ABSR_P5 (0x1u << 5)   
#define PIO_ABSR_P6 (0x1u << 6)   
#define PIO_ABSR_P7 (0x1u << 7)   
#define PIO_ABSR_P8 (0x1u << 8)   
#define PIO_ABSR_P9 (0x1u << 9)   
#define PIO_ABSR_P10 (0x1u << 10) 
#define PIO_ABSR_P11 (0x1u << 11) 
#define PIO_ABSR_P12 (0x1u << 12) 
#define PIO_ABSR_P13 (0x1u << 13) 
#define PIO_ABSR_P14 (0x1u << 14) 
#define PIO_ABSR_P15 (0x1u << 15) 
#define PIO_ABSR_P16 (0x1u << 16) 
#define PIO_ABSR_P17 (0x1u << 17) 
#define PIO_ABSR_P18 (0x1u << 18) 
#define PIO_ABSR_P19 (0x1u << 19) 
#define PIO_ABSR_P20 (0x1u << 20) 
#define PIO_ABSR_P21 (0x1u << 21) 
#define PIO_ABSR_P22 (0x1u << 22) 
#define PIO_ABSR_P23 (0x1u << 23) 
#define PIO_ABSR_P24 (0x1u << 24) 
#define PIO_ABSR_P25 (0x1u << 25) 
#define PIO_ABSR_P26 (0x1u << 26) 
#define PIO_ABSR_P27 (0x1u << 27) 
#define PIO_ABSR_P28 (0x1u << 28) 
#define PIO_ABSR_P29 (0x1u << 29) 
#define PIO_ABSR_P30 (0x1u << 30) 
#define PIO_ABSR_P31 (0x1u << 31) 

#define PIO_SCIFSR_P0 (0x1u << 0)   
#define PIO_SCIFSR_P1 (0x1u << 1)   
#define PIO_SCIFSR_P2 (0x1u << 2)   
#define PIO_SCIFSR_P3 (0x1u << 3)   
#define PIO_SCIFSR_P4 (0x1u << 4)   
#define PIO_SCIFSR_P5 (0x1u << 5)   
#define PIO_SCIFSR_P6 (0x1u << 6)   
#define PIO_SCIFSR_P7 (0x1u << 7)   
#define PIO_SCIFSR_P8 (0x1u << 8)   
#define PIO_SCIFSR_P9 (0x1u << 9)   
#define PIO_SCIFSR_P10 (0x1u << 10) 
#define PIO_SCIFSR_P11 (0x1u << 11) 
#define PIO_SCIFSR_P12 (0x1u << 12) 
#define PIO_SCIFSR_P13 (0x1u << 13) 
#define PIO_SCIFSR_P14 (0x1u << 14) 
#define PIO_SCIFSR_P15 (0x1u << 15) 
#define PIO_SCIFSR_P16 (0x1u << 16) 
#define PIO_SCIFSR_P17 (0x1u << 17) 
#define PIO_SCIFSR_P18 (0x1u << 18) 
#define PIO_SCIFSR_P19 (0x1u << 19) 
#define PIO_SCIFSR_P20 (0x1u << 20) 
#define PIO_SCIFSR_P21 (0x1u << 21) 
#define PIO_SCIFSR_P22 (0x1u << 22) 
#define PIO_SCIFSR_P23 (0x1u << 23) 
#define PIO_SCIFSR_P24 (0x1u << 24) 
#define PIO_SCIFSR_P25 (0x1u << 25) 
#define PIO_SCIFSR_P26 (0x1u << 26) 
#define PIO_SCIFSR_P27 (0x1u << 27) 
#define PIO_SCIFSR_P28 (0x1u << 28) 
#define PIO_SCIFSR_P29 (0x1u << 29) 
#define PIO_SCIFSR_P30 (0x1u << 30) 
#define PIO_SCIFSR_P31 (0x1u << 31) 

#define PIO_DIFSR_P0 (0x1u << 0)   
#define PIO_DIFSR_P1 (0x1u << 1)   
#define PIO_DIFSR_P2 (0x1u << 2)   
#define PIO_DIFSR_P3 (0x1u << 3)   
#define PIO_DIFSR_P4 (0x1u << 4)   
#define PIO_DIFSR_P5 (0x1u << 5)   
#define PIO_DIFSR_P6 (0x1u << 6)   
#define PIO_DIFSR_P7 (0x1u << 7)   
#define PIO_DIFSR_P8 (0x1u << 8)   
#define PIO_DIFSR_P9 (0x1u << 9)   
#define PIO_DIFSR_P10 (0x1u << 10) 
#define PIO_DIFSR_P11 (0x1u << 11) 
#define PIO_DIFSR_P12 (0x1u << 12) 
#define PIO_DIFSR_P13 (0x1u << 13) 
#define PIO_DIFSR_P14 (0x1u << 14) 
#define PIO_DIFSR_P15 (0x1u << 15) 
#define PIO_DIFSR_P16 (0x1u << 16) 
#define PIO_DIFSR_P17 (0x1u << 17) 
#define PIO_DIFSR_P18 (0x1u << 18) 
#define PIO_DIFSR_P19 (0x1u << 19) 
#define PIO_DIFSR_P20 (0x1u << 20) 
#define PIO_DIFSR_P21 (0x1u << 21) 
#define PIO_DIFSR_P22 (0x1u << 22) 
#define PIO_DIFSR_P23 (0x1u << 23) 
#define PIO_DIFSR_P24 (0x1u << 24) 
#define PIO_DIFSR_P25 (0x1u << 25) 
#define PIO_DIFSR_P26 (0x1u << 26) 
#define PIO_DIFSR_P27 (0x1u << 27) 
#define PIO_DIFSR_P28 (0x1u << 28) 
#define PIO_DIFSR_P29 (0x1u << 29) 
#define PIO_DIFSR_P30 (0x1u << 30) 
#define PIO_DIFSR_P31 (0x1u << 31) 

#define PIO_IFDGSR_P0 (0x1u << 0)   
#define PIO_IFDGSR_P1 (0x1u << 1)   
#define PIO_IFDGSR_P2 (0x1u << 2)   
#define PIO_IFDGSR_P3 (0x1u << 3)   
#define PIO_IFDGSR_P4 (0x1u << 4)   
#define PIO_IFDGSR_P5 (0x1u << 5)   
#define PIO_IFDGSR_P6 (0x1u << 6)   
#define PIO_IFDGSR_P7 (0x1u << 7)   
#define PIO_IFDGSR_P8 (0x1u << 8)   
#define PIO_IFDGSR_P9 (0x1u << 9)   
#define PIO_IFDGSR_P10 (0x1u << 10) 
#define PIO_IFDGSR_P11 (0x1u << 11) 
#define PIO_IFDGSR_P12 (0x1u << 12) 
#define PIO_IFDGSR_P13 (0x1u << 13) 
#define PIO_IFDGSR_P14 (0x1u << 14) 
#define PIO_IFDGSR_P15 (0x1u << 15) 
#define PIO_IFDGSR_P16 (0x1u << 16) 
#define PIO_IFDGSR_P17 (0x1u << 17) 
#define PIO_IFDGSR_P18 (0x1u << 18) 
#define PIO_IFDGSR_P19 (0x1u << 19) 
#define PIO_IFDGSR_P20 (0x1u << 20) 
#define PIO_IFDGSR_P21 (0x1u << 21) 
#define PIO_IFDGSR_P22 (0x1u << 22) 
#define PIO_IFDGSR_P23 (0x1u << 23) 
#define PIO_IFDGSR_P24 (0x1u << 24) 
#define PIO_IFDGSR_P25 (0x1u << 25) 
#define PIO_IFDGSR_P26 (0x1u << 26) 
#define PIO_IFDGSR_P27 (0x1u << 27) 
#define PIO_IFDGSR_P28 (0x1u << 28) 
#define PIO_IFDGSR_P29 (0x1u << 29) 
#define PIO_IFDGSR_P30 (0x1u << 30) 
#define PIO_IFDGSR_P31 (0x1u << 31) 

#define PIO_SCDR_DIV_Pos 0
#define PIO_SCDR_DIV_Msk (0x3fffu << PIO_SCDR_DIV_Pos) 
#define PIO_SCDR_DIV(value) ((PIO_SCDR_DIV_Msk & ((value) << PIO_SCDR_DIV_Pos)))

#define PIO_OWER_P0 (0x1u << 0)   
#define PIO_OWER_P1 (0x1u << 1)   
#define PIO_OWER_P2 (0x1u << 2)   
#define PIO_OWER_P3 (0x1u << 3)   
#define PIO_OWER_P4 (0x1u << 4)   
#define PIO_OWER_P5 (0x1u << 5)   
#define PIO_OWER_P6 (0x1u << 6)   
#define PIO_OWER_P7 (0x1u << 7)   
#define PIO_OWER_P8 (0x1u << 8)   
#define PIO_OWER_P9 (0x1u << 9)   
#define PIO_OWER_P10 (0x1u << 10) 
#define PIO_OWER_P11 (0x1u << 11) 
#define PIO_OWER_P12 (0x1u << 12) 
#define PIO_OWER_P13 (0x1u << 13) 
#define PIO_OWER_P14 (0x1u << 14) 
#define PIO_OWER_P15 (0x1u << 15) 
#define PIO_OWER_P16 (0x1u << 16) 
#define PIO_OWER_P17 (0x1u << 17) 
#define PIO_OWER_P18 (0x1u << 18) 
#define PIO_OWER_P19 (0x1u << 19) 
#define PIO_OWER_P20 (0x1u << 20) 
#define PIO_OWER_P21 (0x1u << 21) 
#define PIO_OWER_P22 (0x1u << 22) 
#define PIO_OWER_P23 (0x1u << 23) 
#define PIO_OWER_P24 (0x1u << 24) 
#define PIO_OWER_P25 (0x1u << 25) 
#define PIO_OWER_P26 (0x1u << 26) 
#define PIO_OWER_P27 (0x1u << 27) 
#define PIO_OWER_P28 (0x1u << 28) 
#define PIO_OWER_P29 (0x1u << 29) 
#define PIO_OWER_P30 (0x1u << 30) 
#define PIO_OWER_P31 (0x1u << 31) 

#define PIO_OWDR_P0 (0x1u << 0)   
#define PIO_OWDR_P1 (0x1u << 1)   
#define PIO_OWDR_P2 (0x1u << 2)   
#define PIO_OWDR_P3 (0x1u << 3)   
#define PIO_OWDR_P4 (0x1u << 4)   
#define PIO_OWDR_P5 (0x1u << 5)   
#define PIO_OWDR_P6 (0x1u << 6)   
#define PIO_OWDR_P7 (0x1u << 7)   
#define PIO_OWDR_P8 (0x1u << 8)   
#define PIO_OWDR_P9 (0x1u << 9)   
#define PIO_OWDR_P10 (0x1u << 10) 
#define PIO_OWDR_P11 (0x1u << 11) 
#define PIO_OWDR_P12 (0x1u << 12) 
#define PIO_OWDR_P13 (0x1u << 13) 
#define PIO_OWDR_P14 (0x1u << 14) 
#define PIO_OWDR_P15 (0x1u << 15) 
#define PIO_OWDR_P16 (0x1u << 16) 
#define PIO_OWDR_P17 (0x1u << 17) 
#define PIO_OWDR_P18 (0x1u << 18) 
#define PIO_OWDR_P19 (0x1u << 19) 
#define PIO_OWDR_P20 (0x1u << 20) 
#define PIO_OWDR_P21 (0x1u << 21) 
#define PIO_OWDR_P22 (0x1u << 22) 
#define PIO_OWDR_P23 (0x1u << 23) 
#define PIO_OWDR_P24 (0x1u << 24) 
#define PIO_OWDR_P25 (0x1u << 25) 
#define PIO_OWDR_P26 (0x1u << 26) 
#define PIO_OWDR_P27 (0x1u << 27) 
#define PIO_OWDR_P28 (0x1u << 28) 
#define PIO_OWDR_P29 (0x1u << 29) 
#define PIO_OWDR_P30 (0x1u << 30) 
#define PIO_OWDR_P31 (0x1u << 31) 

#define PIO_OWSR_P0 (0x1u << 0)   
#define PIO_OWSR_P1 (0x1u << 1)   
#define PIO_OWSR_P2 (0x1u << 2)   
#define PIO_OWSR_P3 (0x1u << 3)   
#define PIO_OWSR_P4 (0x1u << 4)   
#define PIO_OWSR_P5 (0x1u << 5)   
#define PIO_OWSR_P6 (0x1u << 6)   
#define PIO_OWSR_P7 (0x1u << 7)   
#define PIO_OWSR_P8 (0x1u << 8)   
#define PIO_OWSR_P9 (0x1u << 9)   
#define PIO_OWSR_P10 (0x1u << 10) 
#define PIO_OWSR_P11 (0x1u << 11) 
#define PIO_OWSR_P12 (0x1u << 12) 
#define PIO_OWSR_P13 (0x1u << 13) 
#define PIO_OWSR_P14 (0x1u << 14) 
#define PIO_OWSR_P15 (0x1u << 15) 
#define PIO_OWSR_P16 (0x1u << 16) 
#define PIO_OWSR_P17 (0x1u << 17) 
#define PIO_OWSR_P18 (0x1u << 18) 
#define PIO_OWSR_P19 (0x1u << 19) 
#define PIO_OWSR_P20 (0x1u << 20) 
#define PIO_OWSR_P21 (0x1u << 21) 
#define PIO_OWSR_P22 (0x1u << 22) 
#define PIO_OWSR_P23 (0x1u << 23) 
#define PIO_OWSR_P24 (0x1u << 24) 
#define PIO_OWSR_P25 (0x1u << 25) 
#define PIO_OWSR_P26 (0x1u << 26) 
#define PIO_OWSR_P27 (0x1u << 27) 
#define PIO_OWSR_P28 (0x1u << 28) 
#define PIO_OWSR_P29 (0x1u << 29) 
#define PIO_OWSR_P30 (0x1u << 30) 
#define PIO_OWSR_P31 (0x1u << 31) 

#define PIO_AIMER_P0 (0x1u << 0)   
#define PIO_AIMER_P1 (0x1u << 1)   
#define PIO_AIMER_P2 (0x1u << 2)   
#define PIO_AIMER_P3 (0x1u << 3)   
#define PIO_AIMER_P4 (0x1u << 4)   
#define PIO_AIMER_P5 (0x1u << 5)   
#define PIO_AIMER_P6 (0x1u << 6)   
#define PIO_AIMER_P7 (0x1u << 7)   
#define PIO_AIMER_P8 (0x1u << 8)   
#define PIO_AIMER_P9 (0x1u << 9)   
#define PIO_AIMER_P10 (0x1u << 10) 
#define PIO_AIMER_P11 (0x1u << 11) 
#define PIO_AIMER_P12 (0x1u << 12) 
#define PIO_AIMER_P13 (0x1u << 13) 
#define PIO_AIMER_P14 (0x1u << 14) 
#define PIO_AIMER_P15 (0x1u << 15) 
#define PIO_AIMER_P16 (0x1u << 16) 
#define PIO_AIMER_P17 (0x1u << 17) 
#define PIO_AIMER_P18 (0x1u << 18) 
#define PIO_AIMER_P19 (0x1u << 19) 
#define PIO_AIMER_P20 (0x1u << 20) 
#define PIO_AIMER_P21 (0x1u << 21) 
#define PIO_AIMER_P22 (0x1u << 22) 
#define PIO_AIMER_P23 (0x1u << 23) 
#define PIO_AIMER_P24 (0x1u << 24) 
#define PIO_AIMER_P25 (0x1u << 25) 
#define PIO_AIMER_P26 (0x1u << 26) 
#define PIO_AIMER_P27 (0x1u << 27) 
#define PIO_AIMER_P28 (0x1u << 28) 
#define PIO_AIMER_P29 (0x1u << 29) 
#define PIO_AIMER_P30 (0x1u << 30) 
#define PIO_AIMER_P31 (0x1u << 31) 

#define PIO_AIMDR_P0 (0x1u << 0)   
#define PIO_AIMDR_P1 (0x1u << 1)   
#define PIO_AIMDR_P2 (0x1u << 2)   
#define PIO_AIMDR_P3 (0x1u << 3)   
#define PIO_AIMDR_P4 (0x1u << 4)   
#define PIO_AIMDR_P5 (0x1u << 5)   
#define PIO_AIMDR_P6 (0x1u << 6)   
#define PIO_AIMDR_P7 (0x1u << 7)   
#define PIO_AIMDR_P8 (0x1u << 8)   
#define PIO_AIMDR_P9 (0x1u << 9)   
#define PIO_AIMDR_P10 (0x1u << 10) 
#define PIO_AIMDR_P11 (0x1u << 11) 
#define PIO_AIMDR_P12 (0x1u << 12) 
#define PIO_AIMDR_P13 (0x1u << 13) 
#define PIO_AIMDR_P14 (0x1u << 14) 
#define PIO_AIMDR_P15 (0x1u << 15) 
#define PIO_AIMDR_P16 (0x1u << 16) 
#define PIO_AIMDR_P17 (0x1u << 17) 
#define PIO_AIMDR_P18 (0x1u << 18) 
#define PIO_AIMDR_P19 (0x1u << 19) 
#define PIO_AIMDR_P20 (0x1u << 20) 
#define PIO_AIMDR_P21 (0x1u << 21) 
#define PIO_AIMDR_P22 (0x1u << 22) 
#define PIO_AIMDR_P23 (0x1u << 23) 
#define PIO_AIMDR_P24 (0x1u << 24) 
#define PIO_AIMDR_P25 (0x1u << 25) 
#define PIO_AIMDR_P26 (0x1u << 26) 
#define PIO_AIMDR_P27 (0x1u << 27) 
#define PIO_AIMDR_P28 (0x1u << 28) 
#define PIO_AIMDR_P29 (0x1u << 29) 
#define PIO_AIMDR_P30 (0x1u << 30) 
#define PIO_AIMDR_P31 (0x1u << 31) 

#define PIO_AIMMR_P0 (0x1u << 0)   
#define PIO_AIMMR_P1 (0x1u << 1)   
#define PIO_AIMMR_P2 (0x1u << 2)   
#define PIO_AIMMR_P3 (0x1u << 3)   
#define PIO_AIMMR_P4 (0x1u << 4)   
#define PIO_AIMMR_P5 (0x1u << 5)   
#define PIO_AIMMR_P6 (0x1u << 6)   
#define PIO_AIMMR_P7 (0x1u << 7)   
#define PIO_AIMMR_P8 (0x1u << 8)   
#define PIO_AIMMR_P9 (0x1u << 9)   
#define PIO_AIMMR_P10 (0x1u << 10) 
#define PIO_AIMMR_P11 (0x1u << 11) 
#define PIO_AIMMR_P12 (0x1u << 12) 
#define PIO_AIMMR_P13 (0x1u << 13) 
#define PIO_AIMMR_P14 (0x1u << 14) 
#define PIO_AIMMR_P15 (0x1u << 15) 
#define PIO_AIMMR_P16 (0x1u << 16) 
#define PIO_AIMMR_P17 (0x1u << 17) 
#define PIO_AIMMR_P18 (0x1u << 18) 
#define PIO_AIMMR_P19 (0x1u << 19) 
#define PIO_AIMMR_P20 (0x1u << 20) 
#define PIO_AIMMR_P21 (0x1u << 21) 
#define PIO_AIMMR_P22 (0x1u << 22) 
#define PIO_AIMMR_P23 (0x1u << 23) 
#define PIO_AIMMR_P24 (0x1u << 24) 
#define PIO_AIMMR_P25 (0x1u << 25) 
#define PIO_AIMMR_P26 (0x1u << 26) 
#define PIO_AIMMR_P27 (0x1u << 27) 
#define PIO_AIMMR_P28 (0x1u << 28) 
#define PIO_AIMMR_P29 (0x1u << 29) 
#define PIO_AIMMR_P30 (0x1u << 30) 
#define PIO_AIMMR_P31 (0x1u << 31) 

#define PIO_ESR_P0 (0x1u << 0)   
#define PIO_ESR_P1 (0x1u << 1)   
#define PIO_ESR_P2 (0x1u << 2)   
#define PIO_ESR_P3 (0x1u << 3)   
#define PIO_ESR_P4 (0x1u << 4)   
#define PIO_ESR_P5 (0x1u << 5)   
#define PIO_ESR_P6 (0x1u << 6)   
#define PIO_ESR_P7 (0x1u << 7)   
#define PIO_ESR_P8 (0x1u << 8)   
#define PIO_ESR_P9 (0x1u << 9)   
#define PIO_ESR_P10 (0x1u << 10) 
#define PIO_ESR_P11 (0x1u << 11) 
#define PIO_ESR_P12 (0x1u << 12) 
#define PIO_ESR_P13 (0x1u << 13) 
#define PIO_ESR_P14 (0x1u << 14) 
#define PIO_ESR_P15 (0x1u << 15) 
#define PIO_ESR_P16 (0x1u << 16) 
#define PIO_ESR_P17 (0x1u << 17) 
#define PIO_ESR_P18 (0x1u << 18) 
#define PIO_ESR_P19 (0x1u << 19) 
#define PIO_ESR_P20 (0x1u << 20) 
#define PIO_ESR_P21 (0x1u << 21) 
#define PIO_ESR_P22 (0x1u << 22) 
#define PIO_ESR_P23 (0x1u << 23) 
#define PIO_ESR_P24 (0x1u << 24) 
#define PIO_ESR_P25 (0x1u << 25) 
#define PIO_ESR_P26 (0x1u << 26) 
#define PIO_ESR_P27 (0x1u << 27) 
#define PIO_ESR_P28 (0x1u << 28) 
#define PIO_ESR_P29 (0x1u << 29) 
#define PIO_ESR_P30 (0x1u << 30) 
#define PIO_ESR_P31 (0x1u << 31) 

#define PIO_LSR_P0 (0x1u << 0)   
#define PIO_LSR_P1 (0x1u << 1)   
#define PIO_LSR_P2 (0x1u << 2)   
#define PIO_LSR_P3 (0x1u << 3)   
#define PIO_LSR_P4 (0x1u << 4)   
#define PIO_LSR_P5 (0x1u << 5)   
#define PIO_LSR_P6 (0x1u << 6)   
#define PIO_LSR_P7 (0x1u << 7)   
#define PIO_LSR_P8 (0x1u << 8)   
#define PIO_LSR_P9 (0x1u << 9)   
#define PIO_LSR_P10 (0x1u << 10) 
#define PIO_LSR_P11 (0x1u << 11) 
#define PIO_LSR_P12 (0x1u << 12) 
#define PIO_LSR_P13 (0x1u << 13) 
#define PIO_LSR_P14 (0x1u << 14) 
#define PIO_LSR_P15 (0x1u << 15) 
#define PIO_LSR_P16 (0x1u << 16) 
#define PIO_LSR_P17 (0x1u << 17) 
#define PIO_LSR_P18 (0x1u << 18) 
#define PIO_LSR_P19 (0x1u << 19) 
#define PIO_LSR_P20 (0x1u << 20) 
#define PIO_LSR_P21 (0x1u << 21) 
#define PIO_LSR_P22 (0x1u << 22) 
#define PIO_LSR_P23 (0x1u << 23) 
#define PIO_LSR_P24 (0x1u << 24) 
#define PIO_LSR_P25 (0x1u << 25) 
#define PIO_LSR_P26 (0x1u << 26) 
#define PIO_LSR_P27 (0x1u << 27) 
#define PIO_LSR_P28 (0x1u << 28) 
#define PIO_LSR_P29 (0x1u << 29) 
#define PIO_LSR_P30 (0x1u << 30) 
#define PIO_LSR_P31 (0x1u << 31) 

#define PIO_ELSR_P0 (0x1u << 0)   
#define PIO_ELSR_P1 (0x1u << 1)   
#define PIO_ELSR_P2 (0x1u << 2)   
#define PIO_ELSR_P3 (0x1u << 3)   
#define PIO_ELSR_P4 (0x1u << 4)   
#define PIO_ELSR_P5 (0x1u << 5)   
#define PIO_ELSR_P6 (0x1u << 6)   
#define PIO_ELSR_P7 (0x1u << 7)   
#define PIO_ELSR_P8 (0x1u << 8)   
#define PIO_ELSR_P9 (0x1u << 9)   
#define PIO_ELSR_P10 (0x1u << 10) 
#define PIO_ELSR_P11 (0x1u << 11) 
#define PIO_ELSR_P12 (0x1u << 12) 
#define PIO_ELSR_P13 (0x1u << 13) 
#define PIO_ELSR_P14 (0x1u << 14) 
#define PIO_ELSR_P15 (0x1u << 15) 
#define PIO_ELSR_P16 (0x1u << 16) 
#define PIO_ELSR_P17 (0x1u << 17) 
#define PIO_ELSR_P18 (0x1u << 18) 
#define PIO_ELSR_P19 (0x1u << 19) 
#define PIO_ELSR_P20 (0x1u << 20) 
#define PIO_ELSR_P21 (0x1u << 21) 
#define PIO_ELSR_P22 (0x1u << 22) 
#define PIO_ELSR_P23 (0x1u << 23) 
#define PIO_ELSR_P24 (0x1u << 24) 
#define PIO_ELSR_P25 (0x1u << 25) 
#define PIO_ELSR_P26 (0x1u << 26) 
#define PIO_ELSR_P27 (0x1u << 27) 
#define PIO_ELSR_P28 (0x1u << 28) 
#define PIO_ELSR_P29 (0x1u << 29) 
#define PIO_ELSR_P30 (0x1u << 30) 
#define PIO_ELSR_P31 (0x1u << 31) 

#define PIO_FELLSR_P0 (0x1u << 0)   
#define PIO_FELLSR_P1 (0x1u << 1)   
#define PIO_FELLSR_P2 (0x1u << 2)   
#define PIO_FELLSR_P3 (0x1u << 3)   
#define PIO_FELLSR_P4 (0x1u << 4)   
#define PIO_FELLSR_P5 (0x1u << 5)   
#define PIO_FELLSR_P6 (0x1u << 6)   
#define PIO_FELLSR_P7 (0x1u << 7)   
#define PIO_FELLSR_P8 (0x1u << 8)   
#define PIO_FELLSR_P9 (0x1u << 9)   
#define PIO_FELLSR_P10 (0x1u << 10) 
#define PIO_FELLSR_P11 (0x1u << 11) 
#define PIO_FELLSR_P12 (0x1u << 12) 
#define PIO_FELLSR_P13 (0x1u << 13) 
#define PIO_FELLSR_P14 (0x1u << 14) 
#define PIO_FELLSR_P15 (0x1u << 15) 
#define PIO_FELLSR_P16 (0x1u << 16) 
#define PIO_FELLSR_P17 (0x1u << 17) 
#define PIO_FELLSR_P18 (0x1u << 18) 
#define PIO_FELLSR_P19 (0x1u << 19) 
#define PIO_FELLSR_P20 (0x1u << 20) 
#define PIO_FELLSR_P21 (0x1u << 21) 
#define PIO_FELLSR_P22 (0x1u << 22) 
#define PIO_FELLSR_P23 (0x1u << 23) 
#define PIO_FELLSR_P24 (0x1u << 24) 
#define PIO_FELLSR_P25 (0x1u << 25) 
#define PIO_FELLSR_P26 (0x1u << 26) 
#define PIO_FELLSR_P27 (0x1u << 27) 
#define PIO_FELLSR_P28 (0x1u << 28) 
#define PIO_FELLSR_P29 (0x1u << 29) 
#define PIO_FELLSR_P30 (0x1u << 30) 
#define PIO_FELLSR_P31 (0x1u << 31) 

#define PIO_REHLSR_P0 (0x1u << 0)   
#define PIO_REHLSR_P1 (0x1u << 1)   
#define PIO_REHLSR_P2 (0x1u << 2)   
#define PIO_REHLSR_P3 (0x1u << 3)   
#define PIO_REHLSR_P4 (0x1u << 4)   
#define PIO_REHLSR_P5 (0x1u << 5)   
#define PIO_REHLSR_P6 (0x1u << 6)   
#define PIO_REHLSR_P7 (0x1u << 7)   
#define PIO_REHLSR_P8 (0x1u << 8)   
#define PIO_REHLSR_P9 (0x1u << 9)   
#define PIO_REHLSR_P10 (0x1u << 10) 
#define PIO_REHLSR_P11 (0x1u << 11) 
#define PIO_REHLSR_P12 (0x1u << 12) 
#define PIO_REHLSR_P13 (0x1u << 13) 
#define PIO_REHLSR_P14 (0x1u << 14) 
#define PIO_REHLSR_P15 (0x1u << 15) 
#define PIO_REHLSR_P16 (0x1u << 16) 
#define PIO_REHLSR_P17 (0x1u << 17) 
#define PIO_REHLSR_P18 (0x1u << 18) 
#define PIO_REHLSR_P19 (0x1u << 19) 
#define PIO_REHLSR_P20 (0x1u << 20) 
#define PIO_REHLSR_P21 (0x1u << 21) 
#define PIO_REHLSR_P22 (0x1u << 22) 
#define PIO_REHLSR_P23 (0x1u << 23) 
#define PIO_REHLSR_P24 (0x1u << 24) 
#define PIO_REHLSR_P25 (0x1u << 25) 
#define PIO_REHLSR_P26 (0x1u << 26) 
#define PIO_REHLSR_P27 (0x1u << 27) 
#define PIO_REHLSR_P28 (0x1u << 28) 
#define PIO_REHLSR_P29 (0x1u << 29) 
#define PIO_REHLSR_P30 (0x1u << 30) 
#define PIO_REHLSR_P31 (0x1u << 31) 

#define PIO_FRLHSR_P0 (0x1u << 0)   
#define PIO_FRLHSR_P1 (0x1u << 1)   
#define PIO_FRLHSR_P2 (0x1u << 2)   
#define PIO_FRLHSR_P3 (0x1u << 3)   
#define PIO_FRLHSR_P4 (0x1u << 4)   
#define PIO_FRLHSR_P5 (0x1u << 5)   
#define PIO_FRLHSR_P6 (0x1u << 6)   
#define PIO_FRLHSR_P7 (0x1u << 7)   
#define PIO_FRLHSR_P8 (0x1u << 8)   
#define PIO_FRLHSR_P9 (0x1u << 9)   
#define PIO_FRLHSR_P10 (0x1u << 10) 
#define PIO_FRLHSR_P11 (0x1u << 11) 
#define PIO_FRLHSR_P12 (0x1u << 12) 
#define PIO_FRLHSR_P13 (0x1u << 13) 
#define PIO_FRLHSR_P14 (0x1u << 14) 
#define PIO_FRLHSR_P15 (0x1u << 15) 
#define PIO_FRLHSR_P16 (0x1u << 16) 
#define PIO_FRLHSR_P17 (0x1u << 17) 
#define PIO_FRLHSR_P18 (0x1u << 18) 
#define PIO_FRLHSR_P19 (0x1u << 19) 
#define PIO_FRLHSR_P20 (0x1u << 20) 
#define PIO_FRLHSR_P21 (0x1u << 21) 
#define PIO_FRLHSR_P22 (0x1u << 22) 
#define PIO_FRLHSR_P23 (0x1u << 23) 
#define PIO_FRLHSR_P24 (0x1u << 24) 
#define PIO_FRLHSR_P25 (0x1u << 25) 
#define PIO_FRLHSR_P26 (0x1u << 26) 
#define PIO_FRLHSR_P27 (0x1u << 27) 
#define PIO_FRLHSR_P28 (0x1u << 28) 
#define PIO_FRLHSR_P29 (0x1u << 29) 
#define PIO_FRLHSR_P30 (0x1u << 30) 
#define PIO_FRLHSR_P31 (0x1u << 31) 

#define PIO_LOCKSR_P0 (0x1u << 0)   
#define PIO_LOCKSR_P1 (0x1u << 1)   
#define PIO_LOCKSR_P2 (0x1u << 2)   
#define PIO_LOCKSR_P3 (0x1u << 3)   
#define PIO_LOCKSR_P4 (0x1u << 4)   
#define PIO_LOCKSR_P5 (0x1u << 5)   
#define PIO_LOCKSR_P6 (0x1u << 6)   
#define PIO_LOCKSR_P7 (0x1u << 7)   
#define PIO_LOCKSR_P8 (0x1u << 8)   
#define PIO_LOCKSR_P9 (0x1u << 9)   
#define PIO_LOCKSR_P10 (0x1u << 10) 
#define PIO_LOCKSR_P11 (0x1u << 11) 
#define PIO_LOCKSR_P12 (0x1u << 12) 
#define PIO_LOCKSR_P13 (0x1u << 13) 
#define PIO_LOCKSR_P14 (0x1u << 14) 
#define PIO_LOCKSR_P15 (0x1u << 15) 
#define PIO_LOCKSR_P16 (0x1u << 16) 
#define PIO_LOCKSR_P17 (0x1u << 17) 
#define PIO_LOCKSR_P18 (0x1u << 18) 
#define PIO_LOCKSR_P19 (0x1u << 19) 
#define PIO_LOCKSR_P20 (0x1u << 20) 
#define PIO_LOCKSR_P21 (0x1u << 21) 
#define PIO_LOCKSR_P22 (0x1u << 22) 
#define PIO_LOCKSR_P23 (0x1u << 23) 
#define PIO_LOCKSR_P24 (0x1u << 24) 
#define PIO_LOCKSR_P25 (0x1u << 25) 
#define PIO_LOCKSR_P26 (0x1u << 26) 
#define PIO_LOCKSR_P27 (0x1u << 27) 
#define PIO_LOCKSR_P28 (0x1u << 28) 
#define PIO_LOCKSR_P29 (0x1u << 29) 
#define PIO_LOCKSR_P30 (0x1u << 30) 
#define PIO_LOCKSR_P31 (0x1u << 31) 

#define PIO_WPMR_WPEN (0x1u << 0) 
#define PIO_WPMR_WPKEY_Pos 8
#define PIO_WPMR_WPKEY_Msk (0xffffffu << PIO_WPMR_WPKEY_Pos) 
#define PIO_WPMR_WPKEY(value) ((PIO_WPMR_WPKEY_Msk & ((value) << PIO_WPMR_WPKEY_Pos)))

#define PIO_WPSR_WPVS (0x1u << 0) 
#define PIO_WPSR_WPVSRC_Pos 8
#define PIO_WPSR_WPVSRC_Msk (0xffffu << PIO_WPSR_WPVSRC_Pos) 

#endif /* _SAM3XA_PIO_COMPONENT_ */
